@@ -83,8 +83,35 @@ public:
     static const int size = 4;
 
     /// Trivial constructor, the quaternion is NOT initialized
+#if OPENVDB_ABI_VERSION_NUMBER >= 8
+    /// @note destructor, copy constructor, assignment operator and
+    ///   move constructor are left to be defined by the compiler (default)
+    Quat() = default;
+#else
     Quat() {}
 
+    /// Copy constructor
+    Quat(const Quat &q)
+    {
+        mm[0] = q.mm[0];
+        mm[1] = q.mm[1];
+        mm[2] = q.mm[2];
+        mm[3] = q.mm[3];
+
+    }
+
+    /// Assignment operator
+    Quat& operator=(const Quat &q)
+    {
+        mm[0] = q.mm[0];
+        mm[1] = q.mm[1];
+        mm[2] = q.mm[2];
+        mm[3] = q.mm[3];
+
+        return *this;
+    }
+#endif
+
     /// Constructor with four arguments, e.g.   Quatf q(1,2,3,4);
     Quat(T x, T y, T z, T w)
     {
@@ -187,16 +214,6 @@ public:
         }
     }
 
-    /// Copy constructor
-    Quat(const Quat &q)
-    {
-        mm[0] = q.mm[0];
-        mm[1] = q.mm[1];
-        mm[2] = q.mm[2];
-        mm[3] = q.mm[3];
-
-    }
-
     /// Reference to the component, e.g.   q.x() = 4.5f;
     T& x() { return mm[0]; }
     T& y() { return mm[1]; }
@@ -305,17 +322,6 @@ public:
     Vec3<T> eulerAngles(RotationOrder rotationOrder) const
     { return math::eulerAngles(Mat3<T>(*this), rotationOrder); }
 
-    /// Assignment operator
-    Quat& operator=(const Quat &q)
-    {
-        mm[0] = q.mm[0];
-        mm[1] = q.mm[1];
-        mm[2] = q.mm[2];
-        mm[3] = q.mm[3];
-
-        return *this;
-    }
-
     /// Equality operator, does exact floating point comparisons
     bool operator==(const Quat &q) const
     {
@@ -502,7 +508,7 @@ public:
     }
 
     /// returns inverse of this
-    Quat inverse(T tolerance = T(0))
+    Quat inverse(T tolerance = T(0)) const
     {
         T d = mm[0]*mm[0] + mm[1]*mm[1] + mm[2]*mm[2] + mm[3]*mm[3];
         if( isApproxEqual(d, T(0.0), tolerance) )
@@ -619,6 +625,11 @@ Mat3<T> bezLerp(const Mat3<T0> &m1, const Mat3<T0> &m2,
 using Quats = Quat<float>;
 using Quatd = Quat<double>;
 
+#if OPENVDB_ABI_VERSION_NUMBER >= 8
+OPENVDB_IS_POD(Quats)
+OPENVDB_IS_POD(Quatd)
+#endif
+
 } // namespace math
 
 
